﻿Fluke Calibration                                           MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek MDO4104 (1 yr)RF VER/9500+1Hd,EPM,HFSG,LO,SWPG
DATE:                  2018-03-15 13:22:54
AUTHOR:                Fluke
REVISION:              $Revision: 22920 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       132
=============================================================================
#
#  Procedure Author:
#        DAC, CAD
#
#  Models covered:
#        MDO4104-3,  MDO4104-6
#
#  Flexible Standard(s) Required:
#
#    Two generators are required for TOI testing: SWPG and HFSG.  A third
#    generator can be configured, if necessary, using the LO flexible alias.
#    If either the SWPG or HFSG meets the minimum use requirements for
#    Single-Sideband Phase Noise, the LO alias can be added to either; a third
#    generator is not required.
#
#        Synthesized Sweep Generator (SWPG):
#          Frequency Range:       50 kHz to 6 GHz
#          Frequency Accuracy:    ± 5 ppm
#          Amplitude Range:       -15 dBm to +10 dBm
#          Amplitude Resolution:  1 dB
#          Example: R&S SMF100A
#
#        High Frequency Signal Generator (HFSG):
#          Frequency Range:       2 to 4.49 GHz
#          Frequency Accuracy:    5 ppm
#          Amplitude Range:       -2 dBm to 0 dBm
#          Amplitude Resolution:  1 dB
#          Example: Anritsu MG3692B
#
#        Local Oscillator (LO):
#          Frequency Range:       2 GHz CW
#          Frequency Accuracy:    5 ppm
#          Amplitude Range:       0 dBm
#          Amplitude Resolution:  1 dB
#          Single-Sideband Phase Noise:
#          -  10 kHz offset: < 90 dBc/Hz
#          - 100 kHz offset: < 95 dBc/Hz
#          -   1 MHz offset: < 113 dBc/Hz
#          Example: Fluke 9640A-LPNX
#
#  Additional Equipment Required:
#
#        Power Splitter (Agilent 11667A):
#          Frequency Range:       DC to 6 GHz
#          Impedance:             50 Ω
#          Equivalent Output SWR:    DC to 4 GHz: < 1.10
#                                 4 GHz to 8 GHz: < 1.20
#          Output Tracking:          DC to 4 GHz: < 0.15 dB
#                                 4 GHz to 8 GHz: < 0.20 dB
#
#  Additional Equipment/Accessories Required (or equivalent):
#
#        Adapters:
#        - Type N (f) to 3.5 mm (f), 50 Ω, DC to 4 GHz
#        - Type N (m) to 3.5 mm (f), 50 Ω, DC to 4 GHz (2 ea.)
#        - BNC Tee (f)-(m)-(f), 50 Ω, 10 MHz
#        - As-needed for the signal generators used.
#
#        Cables:
#        - 3.5 mm (m)-(m), 50 Ω, 10 MHz to 26.5 GHz (2 ea.)
#        - BNC (m)-(m), 50 Ω, 10 MHz, 36" (3 ea.)
#        - As-needed for the signal generators used.
#
#        Other:
#        - 50 Ohm feed through terminator
#        - Power Combiner
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# NOTE: The execution order of this verification procedure has been optimized
# to minimize operator intervention, while retaining the correct sequence for
# reported test results.  For more information about the method used, refer
# to this application note, available at www.flukecal.com:
# Application Note 6001075: Optimizing Execution Sequence in MET/CAL Gold
# Procedures While Retaining Results Order.

  1.001  CALL         Sub Initialize /HFSG
  1.002  CALL         Sub Initialize /LO
  1.003  CALL         Sub Initialize /SWPG

  1.004  MATH         @ScopeCal = "Datron 9500"
  1.005  CALL         Sub Tek MDO4000 Add'l Equipment Min Use Requirements
  1.006  JMPL         END                          @Abort

  1.007  OPBR         -z Do you wish to review connector information and
  1.007  OPBR         precautions for the various types of connections
  1.007  OPBR         employed throughout this procedure?[NO]

  1.008  IF           MEM1
  1.009  CALL         Sub Connector Precautions (Type N)
  1.010  ENDIF

  1.011  JMPL         DANL
  1.012  LABEL        PHASE_NOISE
  1.013  CALL         Sub Tek MDO4000 (1 yr) Phase Noise VER VISA /LO
  1.014  JMPL         TRIGGER_OUTPUT

  1.015  LABEL        DANL
  1.016  CALL         Sub Tek MDO4000 (1 yr) DANL VER VISA
  1.017  JMPL         RESIDUALS

  1.018  LABEL        LEVEL_UNC
  1.019  CALL         Sub Tek MDO4000 (1 yr) Lvl Meas Unc Test VISA /EPM,SWPG
  1.020  CALL         Sub Tek MDO4000 (1 yr) TOI VER VISA /SWPG,HFSG
  1.021  JMPL         PHASE_NOISE

  1.022  LABEL        RESIDUALS
  1.023  CALL         Sub Tek MDO4000 (1 yr) Residual Spurious Resp VER VISA
  1.024  JMPL         LEVEL_UNC

  1.025  LABEL        TRIGGER_OUTPUT
  1.026  MATH         @Chan = 1
  1.027  CALL         Sub Tek DPO4000B (1 yr) Trigger Output VISA

  1.028  LABEL        END
  1.029  END
