﻿Fluke Calibration                                           MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek MDO4104 (1 yr) VER /9500+1Hd,EPM,HFSG,LO,SWPG
DATE:                  2018-03-16 12:26:20
AUTHOR:                Fluke
REVISION:              $Revision: 23115 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       235
CONFIGURATION:         Datron 9500 (G1)
CONFIGURATION:         Datron 9510 on channel 1
CONFIGURATION:         Agilent EPM
CONFIGURATION:         Agilent E9304A on channel 1
CONFIGURATION:         High Freq Signal Generator
CONFIGURATION:         Local Oscillator
CONFIGURATION:         Sweep Generator
STANDARD:              Agilent 11667A
=============================================================================
#
#  Procedure Author:
#        DAC, CAD
#
#  Models covered:
#        MDO4104-3,  MDO4104-6
#
#  Flexible Standard(s) Required:
#
#    Two generators are required for TOI testing: SWPG and HFSG.  A third
#    generator can be configured, if necessary, using the LO flexible alias.
#    If either the SWPG or HFSG meets the minimum use requirements for
#    Single-Sideband Phase Noise, the LO alias can be added to either; a third
#    generator is not required.
#
#        Synthesized Sweep Generator (SWPG):
#          Frequency Range:       50 kHz to 6 GHz
#          Frequency Accuracy:    ± 5 ppm
#          Amplitude Range:       -15 dBm to +10 dBm
#          Amplitude Resolution:  1 dB
#          Example: R&S SMF100A
#
#        High Frequency Signal Generator (HFSG):
#          Frequency Range:       2 to 4.49 GHz
#          Frequency Accuracy:    5 ppm
#          Amplitude Range:       -2 dBm to 0 dBm
#          Amplitude Resolution:  1 dB
#          Example: Anritsu MG3692B
#
#        Local Oscillator (LO):
#          Frequency Range:       2 GHz CW
#          Frequency Accuracy:    5 ppm
#          Amplitude Range:       0 dBm
#          Amplitude Resolution:  1 dB
#          Single-Sideband Phase Noise:
#          -  10 kHz offset: < 90 dBc/Hz
#          - 100 kHz offset: < 95 dBc/Hz
#          -   1 MHz offset: < 113 dBc/Hz
#          Example: Fluke 9640A-LPNX
#
#  Additional Equipment Required:
#
#        Power Splitter (Agilent 11667A):
#          Frequency Range:       DC to 6 GHz
#          Impedance:             50 Ω
#          Equivalent Output SWR:    DC to 4 GHz: < 1.10
#                                 4 GHz to 8 GHz: < 1.20
#          Output Tracking:          DC to 4 GHz: < 0.15 dB
#                                 4 GHz to 8 GHz: < 0.20 dB
#
#  Additional Equipment/Accessories Required (or equivalent):
#
#        Adapters:
#        - Type N (f) to 3.5 mm (f), 50 Ω, DC to 4 GHz
#        - Type N (m) to 3.5 mm (f), 50 Ω, DC to 4 GHz (2 ea.)
#        - BNC Tee (f)-(m)-(f), 50 Ω, 10 MHz
#        - As-needed for the signal generators used.
#
#        Cables:
#        - 3.5 mm (m)-(m), 50 Ω, 10 MHz to 26.5 GHz (2 ea.)
#        - BNC (m)-(m), 50 Ω, 10 MHz, 36" (3 ea.)
#        - As-needed for the signal generators used.
#
#        Other:
#        - 50 Ohm feed through terminator
#        - Power Combiner
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# These statements are here to force the main procedure header to list the
# configuration required by the subprocedures.
  1.001  IF           0
  1.002  M9500                       CH1
  1.003  9500         1GH                          1Vpp           LS    S  L
  1.004  EPM          Zero_and_Cal; PowerSensorA = E9304A
  1.005  IEEE         [@HFSG]
  1.006  IEEE         [@LO]
  1.007  IEEE         [@SWPG]
  1.008  STD          Agilent 11667A
  1.009  ENDIF

  1.010  ASK-   R   Q N              P                                     V

  1.011  IF           NOT(VERSIONCHECK("8.3"))
  1.012  END
  1.013  ENDIF

  1.014  CALL         Sub Display Copyright

  1.015  MATH         @VisaUSB = 1; @VisaLAN = 1
  1.016  CALL         Sub Tek MDO4000 Remote Interface Connection
  1.017  JMPL         END                          @Abort

  1.018  VISA         *CLS;*RST

  1.019  CALL         Sub IEEE-488.2 Identification Query VISA
  1.020  MATH         @DUT_Manufacturer = "Tektronix"
  1.021  CALL         Sub IEEE-488.2 Identification Query Check Response
  1.022  JMPL         END                          @Abort

  1.023  IF           @FirmwareRev < 2.94
  1.024  DISP         This procedure requires DUT firmware version 2.94 or
  1.024  DISP         later.
  1.024  DISP
  1.024  DISP         The DUT's installed firmware is [V @FirmwareRev].
  1.024  DISP
  1.024  DISP         For firmware upgrades, please visit http://www.tek.com.
  1.024  DISP         Firmware files and installation instructions are
  1.024  DISP         available for download.
  1.025  END
  1.026  ENDIF

  1.027  HEAD         PRELIMINARY INSTRUCTIONS
  1.028  TARGET
  1.029  DISP         Ensure a minimum DUT warm-up time of at least
  1.029  DISP         20 minutes has been allowed to elapse, prior
  1.029  DISP         to beginning verification.

  1.030  HEAD         SETUP PROCEDURE EXECUTION PARAMETERS
  1.031  CALL         Sub Select Failed Test Mode
  1.032  CALL         Sub Select Verification Method (No NTHROW)

# Configure variables to be used throughout this procedure.
  1.033  MATH         @Connected = ""; @AlertMode = "Beep"; @MultiHead = 0

  1.034  CALL         Sub Tek MDO/MSO/DPO Self-Test VISA
  1.035  JMPL         END                          @Abort

# -----  Digital Input (MSO) Section  ---------------------------------------

# Tag.Name = Digital_Threshold
# Tag.Start = START_DIGITAL_THRESHOLD
# Tag.End = END_DIGITAL_THRESHOLD
# Tag.Prerequisites =
# Tag.Description =
# Tag.ExecutionTimeInMinutes =
# Tag.Notes =
# Tag.HasOperatorPrompts =
# Tag.IsRequired = 1

  1.038  LABEL        START_DIGITAL_THRESHOLD
  1.039  M9500                       CH1
  1.040  CALL         Sub Tek MSO (1 yr) Digital Threshold VER VISA /9500
  1.041  LABEL        END_DIGITAL_THRESHOLD

# -----  Oscilloscope (DPO) Section  ----------------------------------------

# Tag.Name = Time Domain and Crosstalk
# Tag.Start = START_TIME_DOMAIN_AND_CROSSTALK
# Tag.End = END_TIME_DOMAIN_AND_CROSSTALK
# Tag.Prerequisites =
# Tag.Description =
# Tag.ExecutionTimeInMinutes =
# Tag.Notes =
# Tag.HasOperatorPrompts =
# Tag.IsRequired = 1

  1.042  LABEL        START_TIME_DOMAIN_AND_CROSSTALK

  1.043  CALL         Sub Tek DPO410XB (1 yr) Time Domain VER VISA /9500+1Hd

  1.044  MATH         @Chan = 1
  1.045  CALL         Sub Tek MDO4000 (1 yr) Crosstalk VER VISA /9500


  1.046  MATH         @Chan = 2
  1.047  CALL         Sub Tek MDO4000 (1 yr) Crosstalk VER VISA /9500


  1.048  MATH         @Chan = 3
  1.049  CALL         Sub Tek MDO4000 (1 yr) Crosstalk VER VISA /9500


  1.050  MATH         @Chan = 4
  1.051  CALL         Sub Tek MDO4000 (1 yr) Crosstalk VER VISA /9500
  1.052  LABEL        END_TIME_DOMAIN_AND_CROSSTALK

# -----  RF Input (MDO) Section  --------------------------------------------

# Tag.Name = RF
# Tag.Start = START_RF
# Tag.End = END_RF
# Tag.Prerequisites =
# Tag.Description =
# Tag.ExecutionTimeInMinutes =
# Tag.Notes =
# Tag.HasOperatorPrompts =
# Tag.IsRequired = 1

  1.053  LABEL        START_RF
  1.054  CALL         Sub Tek MDO4104 (1 yr)RF VER/9500+1Hd,EPM,HFSG,LO,SWPG
  1.055  LABEL        END_RF

  1.056  LABEL        END
  1.057  VISA         *CLS;*RST

  1.058  IF           @Abort
  1.059  HEAD         {V E R I F I C A T I O N   A B O R T E D}
  1.060  ENDIF

  1.061  END
